==> bce-java-sdk-0.10.219-sources.jar: com/baidubce/services/mms/model/SourceAndDescRequest.java <==
/*
 * Copyright (C) 2020 Baidu, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package com.baidubce.services.mms.model;

import com.baidubce.auth.BceCredentials;
import com.baidubce.model.AbstractBceRequest;

/**
 * MMS video/image and desc request.
 */
public class SourceAndDescRequest extends AbstractBceRequest {

    private String source;
    private String description;

    public SourceAndDescRequest() {
    }

    public SourceAndDescRequest(String source, String description) {
        this.source = source;
        this.description = description;
    }

    @Override
    public AbstractBceRequest withRequestCredentials(BceCredentials credentials) {
        this.setRequestCredentials(credentials);
        return this;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    @Override
    public String toString() {
        return "InsertVideoRequest{" +
                "source='" + source + '\'' +
                ", description='" + description + '\'' +
                '}';
    }
}

==> bce-java-sdk-0.10.290-sources.jar: com/baidubce/services/mms/model/SourceAndDescRequest.java <==
/*
 * Copyright (C) 2020 Baidu, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package com.baidubce.services.mms.model;

import com.baidubce.auth.BceCredentials;
import com.baidubce.model.AbstractBceRequest;

/**
 * MMS video/image and desc request.
 */
public class SourceAndDescRequest extends AbstractBceRequest {

    private String source;
    private String description;
    private String notification;

    public SourceAndDescRequest() {
    }

    public SourceAndDescRequest(String source, String description) {
        this.source = source;
        this.description = description;
    }

    @Override
    public AbstractBceRequest withRequestCredentials(BceCredentials credentials) {
        this.setRequestCredentials(credentials);
        return this;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getNotification() {
        return notification;
    }

    public void setNotification(String notification) {
        this.notification = notification;
    }

    @Override
    public String toString() {
        return "SourceAndDescRequest{" +
                "source='" + source + '\'' +
                ", description='" + description + '\'' +
                ", notification='" + notification + '\'' +
                '}';
    }
}
